/* Copyright 2016 Dirk Duschinger */

//////////////////////////////////////
// author : Dirk Duschinger         //
// email  : dirk.duschigner@cern.ch //
//////////////////////////////////////

#include <cstdlib>

#include "ROOTTermBrowser.h"

void quit() {
  endwin();
}

int main(int argc, const char* argv[]) {
  for (size_t i = 0; i < argc; i++)
  {
    std::string arg = argv[i];
    if ((arg == "-h") || (arg == "-?") || (arg == "--help") || (arg == "--usage"))
    {
      std::cout<<"usage: rootbrowsetty [-h] FILE [File ...]\n\n";
      std::cout<<"Display ROOT files with a tty alternative to the TBrowser\n\n";
      std::cout<<"positional arguments:\n";
      std::cout<<"  FILE               Input file\n\n";
      std::cout<<"optional arguments:\n";
      std::cout<<"  -h, --help         show this help message and exit\n\n";
      std::cout<<"Examples:\n";
      std::cout<<"- rootls example.root\n";
      std::cout<<"  Browse contents of the ROOT file 'example.root'.\n\n";
      std::cout<<"- rootls file1.root file2.root\n";
      std::cout<<"  Browse contents of ROOT files 'file1.root' and 'file2.root'.\n\n";
      std::cout<<"- rootls *.root\n";
      std::cout<<"  Browse contents of ROOT files whose name ends with '.root'.\n";
      return 0;
    }
  }
  if (argc < 2) {
    std::cout << "usage: rootbrowsetty [-h] ROOTFILE...\n";
    return 1;
  }

  ROOTReader* rr = new ROOTReader(argc, argv);
  rr->ReadFiles();
  // std::cout<<*(rr->GetRPE())<<"\n";

  CursesOutputHandler* coh = new CursesOutputHandler(rr);
  CursesInputHandler* cih = new CursesInputHandler();
  cih->initialize(coh);
  cih->Cycle();
  refresh();
  atexit(quit);
  endwin();
  delete coh;
  delete cih;
  return 0;
}



